/*
 * Email Notify
 * Copyright: (C) 2008 by Antonio Nastasi
 * Email: sifcenter (at) gmail.it
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef EMAILCHECKER_H
#define EMAILCHECKER_H

#include "account.h"

#include <QThread>
#include <QDebug>
#include <QSslSocket>

class EmailChecker : public QThread
{
  Q_OBJECT
  public:
    EmailChecker();
    ~EmailChecker();
    void run();
    void setAccount( Account *account );
    void checkEmails();

  private:
    enum CommandType {
      LOGIN,
      PASSWORD,
      STAT
    };

    enum ConnectionState {
      NO_CONNECTED,
      CONNECTED,
      VERIFY_USER,
      VERIFY_PASSWORD,
      CMD_STAT
    };

    ConnectionState state;
    QSslSocket socket;
    void sendMessage( CommandType );
    void updateText( QString );
    inline void closeConnection();
    Account *account_;

  private slots:
    void threadFinished();
    void getMessage();
    void socketEncrypted();
    void socketConnected();
    void errorConnection( QAbstractSocket::SocketError );

  signals:
    void updatedText( QString );
};
#endif
