/*
 * Email Notify
 * Copyright: (C) 2008 by Antonio Nastasi
 * Email: sifcenter (at) gmail.it
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "configdialog.h"

#include <KPageDialog>
#include <kdebug.h>

ConfigDialog::ConfigDialog()
{
  setFaceType( KPageDialog::List );
  setCaption( "EmailNotify Configure" );
  setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
  connect( this, SIGNAL( buttonClicked( KDialog::ButtonCode ) ), this,
           SLOT( slotButtonClicked( KDialog::ButtonCode ) ) );
  // grep configuration file
  // FIXME from pointer by plasma_emailnotify.h
  config = new KConfig("emailnotifyrc");
  generalGroup = new KConfigGroup(config,"General");

  // set the account page
  widAccount = new EditAccount( this, generalGroup );
  KPageWidgetItem *page = new KPageWidgetItem( widAccount, "Account" );
  page->setHeader( "Account Page" );
  page->setIcon( KIcon( "user" ) );
  addPage( page );

  // set the appearance page
  widAppearance = new EditAppearance( this, generalGroup );
  page = new KPageWidgetItem( widAppearance, "Appearance" );
  page->setHeader( "Appearance Page" );
  page->setIcon( KIcon( "games-config-background" ) );
  addPage( page );

  //set the notification page
  widNotification = new EditNotification( this, generalGroup );
  page = new KPageWidgetItem( widNotification, "Notification" );
  page->setHeader( "Notification Page" );
  page->setIcon( KIcon( "preferences-desktop-notification" ) );
  addPage( page );
}

ConfigDialog::~ConfigDialog()
{
  delete widAccount;
  delete widNotification;
  delete widAppearance;
  delete generalGroup;
  delete config;
}

void ConfigDialog::loadConfig()
{
  //FIXME check if general is not null
  config->reparseConfiguration ();
  widAccount->loadConfig();
  widNotification->loadConfig();
  widAppearance->loadConfig();
}

void ConfigDialog::saveConfig()
{
  //FIXME check if general is not null
  widAccount->saveConfig();
  widNotification->saveConfig();
  widAppearance->saveConfig();
  generalGroup->config()->sync();

  kDebug() << "Config updated";
  emit configUpdated();
}

void ConfigDialog::slotButtonClicked( KDialog::ButtonCode button )
{
  switch( button )
  {
     //FIXME media->stop();
    case KDialog::Ok:
      saveConfig();
    case KDialog::Cancel:
      hide();
      break;
    case KDialog::Apply:
      saveConfig();
      break;
    default:
      break;
  }
}

void ConfigDialog::show()
{
  loadConfig();
  KPageDialog::show();
}
