/*
 * Email Notify
 * Copyright: (C) 2008 by Antonio Nastasi
 * Email: sifcenter (at) gmail.it
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "editaccount.h"

#include <kdebug.h>

EditAccount::EditAccount( QWidget *parent, KConfigGroup *generalGroup )
  : QWidget( parent )
{
  setupUi(this);
  connect( sslCheck_,      SIGNAL( stateChanged( int ) ),
           this,           SLOT( sslStateChanged( int ) ) );
  connect( protocolCombo_, SIGNAL( currentIndexChanged( QString ) ),
           this,           SLOT( slotProtocolIndexChanged( QString ) ) );
  connect( serversCombo_,  SIGNAL( currentIndexChanged ( int ) ),
           this,           SLOT ( slotNameServerChanged( int ) ) );

  generalGroup_ = generalGroup;
  addServersList();
}

EditAccount::~EditAccount()
{
}

void EditAccount::addServersList()
{
  // The server List
  serversList_ = new QStringList();
  serversList_->append("Gmail pop.gmail.com imap.gmail.com true");
  serversList_->append("Yahoo pop.mail.yahoo.com nohost false");
  serversList_->append("Hotmail pop3.live.com nohost true");
  // Insert the list into ComboBox
  foreach(QString server, *serversList_ )
  {
    serversCombo_->addItem( server.section( " ", 0, 0 ) );
  }

  serversCombo_->addItem( "Other" );
}

void EditAccount::slotNameServerChanged( int index )
{
  if( index == serversList_->count() )
  {
    //if the current item is "Other" set enable the fields
    serverEdit_->setEnabled( true );
    portSpin_->setEnabled( true );
    protocolCombo_->setEnabled( true );
    sslCheck_->setEnabled( true );
    return;
  }

  // Set the values of the fields
  QString current = serversList_->at( index );
  sslCheck_->setChecked( QVariant( current.section( " ", 3, 3 ) ).toBool() );
  protocolCombo_->setCurrentIndex( 1 );
  serverEdit_->setText( current.section( " ", 1, 1 ) );
  slotProtocolIndexChanged( "POP3" );

  // Disable the fields
  protocolCombo_->setEnabled( current.section( " ", 2, 2 ).contains( "nohost" ) ? false : true );
  serverEdit_->setEnabled( false );
  portSpin_->setEnabled( false );
  sslCheck_->setEnabled( false );
}

void EditAccount::sslStateChanged( const int state )
{
  // Adjust port
  slotProtocolIndexChanged( protocolCombo_->currentText() );
}

void EditAccount::slotProtocolIndexChanged( const QString text )
{
  int port = 0;
  if( ! text.compare( "IMAP" ) )
  {
    port = ( sslCheck_->checkState() == Qt::Checked ) ? 993 : 143;
    if( ! serversCombo_->currentText().startsWith( "Other" ) )
    {
      QString current = serversList_->at( serversCombo_->currentIndex() );
      serverEdit_->setText( current.section( " ", 2, 2 ) );
    }
  }
  else if( ! text.compare( "POP3" ) )
  {
    port = ( sslCheck_->checkState() == Qt::Checked ) ? 995 : 110;
    if( ! serversCombo_->currentText().startsWith( "Other" ) )
    {
      QString current = serversList_->at( serversCombo_->currentIndex() );
      serverEdit_->setText( current.section( " ", 1, 1 ) );
    }
  }
  portSpin_->setValue( port );
}

void EditAccount::loadConfig()
{
  bool check;
  int found = protocolCombo_->findText(generalGroup_->readEntry( "Protocol", "" ) );
  protocolCombo_->setCurrentIndex( ( found == -1 ) ? 1 : found );

  serverEdit_->setText( generalGroup_->readEntry( "Server", "" ) );
  portSpin_->setValue( generalGroup_->readEntry( "Port", 143 ) );

  check = generalGroup_->readEntry( "SSL", false );
  sslCheck_->setCheckState( ( check ) ? Qt::Checked : Qt::Unchecked );

  intervalSpin_->setValue( generalGroup_->readEntry( "Interval", 60 ) );
  usernameEdit_->setText( generalGroup_->readEntry( "Login", "" ) );
  passwordEdit_->setText( QByteArray::fromBase64( generalGroup_->readEntry( "Password", "" ).toUtf8() ) );

  QString server = generalGroup_->readEntry( "ServerName", "" );

  // Set current name server and adjust the fields
  int founded = serversCombo_->findText( server );
  if( founded != -1 )
  {
    serversCombo_->setCurrentIndex( founded );
  }
  else
  {
    //FIXME
    serversCombo_->setCurrentIndex( 3 );
  }
}

void EditAccount::saveConfig()
{
  generalGroup_->writeEntry( "ServerName", serversCombo_->currentText() );
  generalGroup_->writeEntry( "Server", serverEdit_->text() );
  generalGroup_->writeEntry( "Port", portSpin_->value() );
  generalGroup_->writeEntry( "Protocol", protocolCombo_->itemText(protocolCombo_->currentIndex()));
  if(sslCheck_->checkState() == Qt::Checked)
    generalGroup_->writeEntry( "SSL", "true" );
  else
    generalGroup_->writeEntry( "SSL", "false" );
  generalGroup_->writeEntry( "Interval",  intervalSpin_->value() );
  generalGroup_->writeEntry( "Login", usernameEdit_->text() );
  generalGroup_->writeEntry( "Password",  passwordEdit_->text().toUtf8().toBase64() );
}

#include "editaccount.moc"
